@@ -19,8 +19,9 @@
 package validators;
 
 
-import java.io.InputStream;
 import java.io.IOException;
+import java.io.InputStream;
+
 import javax.servlet.jsp.tagext.PageData;
 import javax.servlet.jsp.tagext.TagLibraryValidator;
 import javax.servlet.jsp.tagext.ValidationMessage;
@@ -34,9 +35,7 @@ import javax.servlet.jsp.tagext.ValidationMessage;
  * of your JSP page.
  *
  * @author Craig McClanahan
- * @version $Revision: 467217 $ $Date: 2006-10-24 05:14:34 +0200 (Tue, 24 Oct 2006) $
  */
-
 public class DebugValidator extends TagLibraryValidator {
 
 
@@ -57,6 +56,7 @@ public class DebugValidator extends TagLibraryValidator {
      * @param uri The value of the URI argument in this directive
      * @param page The page data for this page
      */
+    @Override
     public ValidationMessage[] validate(String prefix, String uri,
                                         PageData page) {
 
@@ -76,7 +76,7 @@ public class DebugValidator extends TagLibraryValidator {
         }
         System.out.println();
         System.out.println("-----------------------------------------------");
-        return (null);
+        return null;
 
     }
 
